@@ -464,7 +464,8 @@ void CBEIDApp::FillIDData(CTLVBuffer & oTLVBuffer, BEID_ID_Data *ptData)
         oTLVBuffer.FillUTF8Data(0x07,  ptData->name);
         oTLVBuffer.FillUTF8Data(0x08,  ptData->firstName1);
         oTLVBuffer.FillUTF8Data(0x09,  ptData->firstName3);
-        strcpy(ptData->nationality, "be");
+        char szNat[100] = {0};
+        oTLVBuffer.FillUTF8Data(0x0A,  szNat);
         oTLVBuffer.FillUTF8Data(0x0B,  ptData->birthLocation);
         oTLVBuffer.FillDateData(0x0C,  ptData->birthDate);
         CTLV *pTagData = NULL;
@@ -482,6 +483,10 @@ void CBEIDApp::FillIDData(CTLVBuffer & oTLVBuffer, BEID_ID_Data *ptData)
         }
         oTLVBuffer.FillUTF8Data(0x0E,  ptData->nobleCondition);
         oTLVBuffer.FillLongData(0x0F, &ptData->documentType);
+        if(ptData->documentType < 10)
+        {
+            strcpy(ptData->nationality, "be");
+        }
         ptData->extendedMinority = 0;
         ptData->whiteCane = 0;
         ptData->yellowCane = 0;
