@@ -183,10 +183,15 @@ long COpenSCReader::ReadFile(const unsigned char *ucFile, int iFileLen, unsigned
    		sc_append_path_id(&tPath, ucFile, iFileLen);
         tPath.count = -1;
         tPath.type = SC_PATH_TYPE_PATH;
-        if(SC_NO_ERROR != (lRet = sc_pkcs15_read_file2(m_p15Card, &tPath, pucOutput, (unsigned int*)pulOutLen, NULL)))
+        size_t outLen = *pulOutLen;
+        if(SC_NO_ERROR != (lRet = sc_pkcs15_read_file2(m_p15Card, &tPath, pucOutput, &outLen, NULL)))
         {
             *pulOutLen = 0;
         }
+        else
+        {
+            *pulOutLen = outLen;
+        }
         ConvertOpenSCError(lRet, ptStatus);
     }
     return lRet;
