@@ -285,11 +285,7 @@ static t_lang_info lang_infos[SC_MAX_READERS];
 /* Language support for the GUI messages */
 #ifdef HAVE_GUI
 
-#ifndef __APPLE__
 #define BTN_KEYB_SHORTCUT "&"
-#else
-#define BTN_KEYB_SHORTCUT "_"
-#endif
 
 static char *app_msg[] = {
 	"Identity",
@@ -849,7 +845,7 @@ static int belpic_finish(struct sc_card *card)
 /* Temp storage */
 static int appletversion = -1;
 static int globalosversion = -1;
-unsigned char carddata[CARDDATA_LEN];
+static unsigned char carddata[CARDDATA_LEN];
 
 static int belpic_match_card(struct sc_card *card)
 {
@@ -960,6 +956,9 @@ static int belpic_init(struct sc_card *card)
 #ifdef HAVE_GUI
 #ifdef _WIN32
     modgui = (void *)scdl_open("beidgui.dll");
+#elif defined (__APPLE__)
+    /* QT complains if not full path given on Mac */
+    modgui = (void *)scdl_open("/usr/local/lib/libbeidgui.dylib");
 #else
     modgui = (void *)scdl_open("libbeidgui.so");
 #endif
