@@ -174,8 +174,13 @@ static int pcsc_transmit(struct sc_reader *reader, struct sc_slot_info *slot,
 		rv = SCardTransmit(card, &sSendPci, sendbuf, dwSendLength,
 				   &sRecvPci, recvbuf, &dwRecvLength);
 	} else {
+#ifndef __OLD_PCSC_API__
 		rv = SCardControl(card, 0, sendbuf, dwSendLength,
 				  recvbuf, dwRecvLength, &dwRecvLength);
+#else
+		rv = SCardControl(card, sendbuf, dwSendLength,
+				  recvbuf, &dwRecvLength);
+#endif
 	}
 
 	if (rv != SCARD_S_SUCCESS) {
@@ -500,7 +505,7 @@ static int pcsc_init(struct sc_context *ctx, void **reader_data)
 	LONG rv;
 	DWORD reader_buf_size = 0;
 	char *reader_buf = NULL, *p = NULL;
-	LPCTSTR mszGroups = NULL;
+	char *mszGroups = NULL;
 	SCARDCONTEXT pcsc_ctx;
 	int r, i;
 	struct pcsc_global_private_data *gpriv;
